Skip to contents

The gradient is taken with respect to the item parameters and organized to be conformable with Matrix::bdiag(mle$var.cov). When evaluating the gradient under the null hypothesis of no DIF, the optional argument theta can be provided. It replaces the item-specific values of d_fun in the gradient computation.

Usage

grad_d(mle, theta = NULL, type = 3)

Arguments

mle

the output of get_model_parms

theta

(optional) the scaling parameter. Replaces item-specific values of d_fun if provided.

type

a number in 1:3 indicating which version of delta to compute. See description for details.

Value

A matrix in which the columns are the gradient vectors of d_fun, for each item and threshold.

See also