dot-onLoad.Rd
Registers S3 methods at load time: - print for class "rdif" - plot for class "rdif" - summary for class "rdif"
.onLoad(libname, pkgname)
Character string with the path to the package library.
Character string with the package name.
No return value, called for side effects when the package loads.